[−][src]Enum structopt_flags::LevelFilter
An enum representing the available verbosity level filters of the logger.
A LevelFilter may be compared directly to a Level. Use this type
to get and set the maximum log level with max_level() and set_max_level.
Variants
OffA level lower than all log levels.
ErrorCorresponds to the Error log level.
WarnCorresponds to the Warn log level.
InfoCorresponds to the Info log level.
DebugCorresponds to the Debug log level.
TraceCorresponds to the Trace log level.
Methods
impl LevelFilter[src]
pub fn max() -> LevelFilter[src]
Returns the most verbose logging level filter.
pub fn to_level(&self) -> Option<Level>[src]
Converts self to the equivalent Level.
Returns None if self is LevelFilter::Off.